@@ -1,38 +1,38 @@
 # Copyright (c) Naas Team.
 # Distributed under the terms of the GNU AGPL License.
-from .types import t_tz, error_busy, error_reject, copy_button
+from .ntypes import t_tz, error_busy, error_reject, copy_button
 from IPython.core.display import display, Javascript, HTML
 from .runner.notifications import Notifications
-from .runner.callback import Callback
 from .dependency import Dependency
 from .runner.env_var import n_env
 from .runner.proxy import Domain
 from .scheduler import Scheduler
+from .callback import Callback
 import ipywidgets as widgets
 from .assets import Assets
 from .secret import Secret
-from .runner import Runner
 from .api import Api
 import requests
 import os
+import sys
 
-__version__ = "1.5.30"
+__version__ = "1.8.10"
 __github_repo = "jupyter-naas/naas"
 __doc_url = "https://naas.gitbook.io/naas/"
 __canny_js = '<script>!function(w,d,i,s){function l(){if(!d.getElementById(i)){var f=d.getElementsByTagName(s)[0],e=d.createElement(s);e.type="text/javascript",e.async=!0,e.src="https://canny.io/sdk.js",f.parentNode.insertBefore(e,f)}}if("function"!=typeof w.Canny){var c=function(){c.q.push(arguments)};c.q=[],w.Canny=c,"complete"===d.readyState?l():w.attachEvent?w.attachEvent("onload",l):w.addEventListener("load",l,!1)}}(window,document,"canny-jssdk","script");</script>'  # noqa: E501
 __crisp = '<script type="text/javascript">window.$crisp=[];window.CRISP_WEBSITE_ID="a64b999e-e44c-44ee-928f-5cd0233f9586";(function(){d=document;s=d.createElement("script");s.src="https://client.crisp.chat/l.js";s.async=1;d.getElementsByTagName("head")[0].appendChild(s);})();</script>'  # noqa: E501
 __location__ = os.getcwd()
 
-scheduler = Scheduler()
-secret = Secret()
-runner = Runner()
-api = Api(True)
-webhook = Api()
-assets = Assets()
-dependency = Dependency()
-notifications = Notifications()
-callback = Callback()
-Domain = Domain()
+if len(sys.argv) == 0 or (len(sys.argv) > 0 and sys.argv[0] != "-m"):
+    scheduler = Scheduler()
+    secret = Secret()
+    api = Api(True)
+    webhook = Api()
+    assets = Assets()
+    dependency = Dependency()
+    notifications = Notifications()
+    callback = Callback()
+    Domain = Domain()
 
 
 def version():
